@@ -59,7 +59,7 @@
 #define ACCOUNT_DIR "/apps/evolution/mail"
 #define ACCOUNTS    ACCOUNT_DIR"/accounts"
 
-#define EVOLUTION_DESKTOP_FILE "/usr/share/applications/evolution-mail.desktop"
+#define EVOLUTION_DESKTOP_FILE "/usr/share/applications/evolution.desktop"
 
 #define UNREAD_DATA "unread"
 
@@ -74,6 +74,7 @@ static IndicateServer *server     = NULL;
 static GSList         *indicators = NULL;
 static gint            n_accounts = 0;
 
+static IndicateIndicator  *pop_indicator  = NULL;
 static NotifyNotification *notification   = NULL;
 static ca_context         *canberra_cxt   = NULL;
 static ca_proplist        *canberra_props = NULL;
@@ -99,7 +100,7 @@ void org_gnome_shell_started_done (EPlugin *ep, ESEventTargetShell *t);
 int         e_plugin_lib_enable               (EPluginLib *ep, int enable);
 GtkWidget * e_plugin_lib_get_configure_widget (EPlugin *epl);
 
-static void show_evolution (gpointer arg0, gpointer arg1);
+static void show_evolution (gpointer arg0, guint timestamp, gpointer arg1);
 
 static void show_evolution_in_indicator_applet (void);
 static void hide_evolution_in_indicator_applet (void);
@@ -237,7 +238,7 @@ org_gnome_mail_new_notify (EPlugin *ep, EMEventTargetFolder *t)
 
 	g_static_mutex_lock (&mlock);
 
-  g_debug ("EI:mail_new_notify");
+  g_debug ("EI:mail_new_notify: %s", t->uri);
 
   message_count += t->new;
  
@@ -258,22 +259,25 @@ org_gnome_mail_new_notify (EPlugin *ep, EMEventTargetFolder *t)
             break;
           }
       }
-      if (indicator)
-        {
-          gint count;
-            
-          count = get_indicator_unread_count (indicator);
-          set_indicator_unread_count (indicator, count + t->new);
+    if (!indicator && pop_indicator) /* Use pop (default) indicator */
+      indicator = pop_indicator;
+    
+    if (indicator)
+      {
+        gint count;
+          
+        count = get_indicator_unread_count (indicator);
+        set_indicator_unread_count (indicator, count + t->new);
 
-          indicate_indicator_set_property (indicator,
-                                           INDICATE_INDICATOR_MESSAGES_PROP_ATTENTION,
-                                           "true");
-        }
-      else
-        {
-          g_warning ("Unable to find account that matches %s", t->uri);
-        }
-  }
+        indicate_indicator_set_property (indicator,
+                                         INDICATE_INDICATOR_MESSAGES_PROP_ATTENTION,
+                                         "true");
+      }
+    else
+      {
+        g_warning ("Unable to find account that matches %s", t->uri);
+      }
+    }
 
   /* Show bubble */
   if (show_bubble)
@@ -288,8 +292,8 @@ org_gnome_mail_new_notify (EPlugin *ep, EMEventTargetFolder *t)
     }
 
     trans = g_dngettext (PACKAGE, 
-                         _("%d New Message"), 
-                         _("%d New Messages"),
+                         "%d New Message", 
+                         "%d New Messages",
                          message_count);
     
     title = g_strdup_printf (trans, message_count);
@@ -470,6 +474,8 @@ create_indicator (const gchar *url, const gchar *name)
   g_signal_connect (indicator, "user-display",
                     G_CALLBACK (show_evolution), NULL);
 
+  g_debug ("New Indicator: %s %s", name, url);
+
   return indicator;
 }
 
@@ -545,7 +551,7 @@ update_accounts (void)
 {
   GSList   *accounts;
   GError   *error = NULL;
-  gint      i = 0;
+  gint      i = 1;
   GTimeVal  timeval = { 0 };
   
   g_get_current_time (&timeval);
@@ -596,7 +602,21 @@ update_accounts (void)
                                         NULL);
 
           /* Check to see account already exists and, if not, create it */
-          indicator = find_indicator_for_url (indicators, data.url);
+          if (data.url && g_str_has_prefix (data.url, "pop:"))
+            {
+              if (pop_indicator == NULL)
+                {
+                  pop_indicator = create_indicator ("pop:",
+                                                  g_dgettext ("evolution-2.28",
+                                                                "Inbox"));
+                  g_debug ("New Inbox inidicator");
+                }
+              indicator = pop_indicator;
+            }
+          else
+            {
+              indicator = find_indicator_for_url (indicators, data.url);
+            }
           if (indicator)
             {
               old_list = g_slist_remove (old_list, indicator);
@@ -651,6 +671,19 @@ on_accounts_changed (GConfClient *gclient,
   update_accounts ();
 }
 
+#define EVO_CONTACTS_CMD  "evolution -c contacts"
+#define EVO_COMPOSE_CMD   "evolution mailto:"
+
+static void
+command_item_activate (DbusmenuMenuitem * mi, guint timestamp, gpointer user_data)
+{
+	gchar * command = (gchar *)user_data;
+	if (!g_spawn_command_line_async(command, NULL)) {
+		g_warning("Unable to execute command '%s'", command);
+	}
+	return;
+}
+
 int
 e_plugin_lib_enable (EPluginLib *ep, int enable)
 {
@@ -690,6 +723,22 @@ e_plugin_lib_enable (EPluginLib *ep, int enable)
     g_signal_connect (server, "server-display",
                       G_CALLBACK (show_evolution), NULL);
 
+	DbusmenuServer * menu_server = dbusmenu_server_new("/messaging/commands");
+	DbusmenuMenuitem * root = dbusmenu_menuitem_new();
+
+	DbusmenuMenuitem * mi = dbusmenu_menuitem_new();
+	dbusmenu_menuitem_property_set(mi, DBUSMENU_MENUITEM_PROP_LABEL, _("Compose New Message"));
+	g_signal_connect(G_OBJECT(mi), DBUSMENU_MENUITEM_SIGNAL_ITEM_ACTIVATED, G_CALLBACK(command_item_activate), EVO_COMPOSE_CMD);
+	dbusmenu_menuitem_child_append(root, mi);
+
+	mi = dbusmenu_menuitem_new();
+	dbusmenu_menuitem_property_set(mi, DBUSMENU_MENUITEM_PROP_LABEL, _("Contacts"));
+	g_signal_connect(G_OBJECT(mi), DBUSMENU_MENUITEM_SIGNAL_ITEM_ACTIVATED, G_CALLBACK(command_item_activate), EVO_CONTACTS_CMD);
+	dbusmenu_menuitem_child_append(root, mi);
+
+	dbusmenu_server_set_root(menu_server, root);
+	indicate_server_set_menu(server, menu_server);
+
     client = gconf_client_get_default ();
     gconf_client_add_dir (client, CONF_DIR, GCONF_CLIENT_PRELOAD_NONE, NULL);
 
@@ -925,52 +974,8 @@ org_gnome_get_prefs (EPlugin *epl, EConfigHookItemFactoryData *data)
  *
  */
 
-/*
- * Taken from libtomboy, (C) 2008 Novell, LGPL v2 or later
- */
 static void
-tomboy_window_override_user_time (GtkWindow *window)
-{
-	guint32 ev_time = gtk_get_current_event_time();
-
-	if (ev_time == 0) {
-		/* 
-		 * FIXME: Global keypresses use an event filter on the root
-		 * window, which processes events before GDK sees them.
-		 */
-		//ev_time = tomboy_keybinder_get_current_event_time ();
-    ev_time = GDK_CURRENT_TIME;
-	}
-	if (ev_time == 0) {
-		gint ev_mask = gtk_widget_get_events (GTK_WIDGET(window));
-		if (!(ev_mask & GDK_PROPERTY_CHANGE_MASK)) {
-			gtk_widget_add_events (GTK_WIDGET (window),
-					       GDK_PROPERTY_CHANGE_MASK);
-		}
-
-		/* 
-		 * NOTE: Last resort for D-BUS or other non-interactive
-		 *       openings.  Causes roundtrip to server.  Lame. 
-		 */
-		ev_time = gdk_x11_get_server_time (GTK_WIDGET(window)->window);
-	}
-
-	gdk_x11_window_set_user_time (GTK_WIDGET(window)->window, ev_time);
-}
-
-static void 
-really_present_window (GtkWindow *window)
-{
-	if (!GTK_WIDGET_REALIZED (window))
-		gtk_widget_realize (GTK_WIDGET (window));
-
-	tomboy_window_override_user_time (window);
-
-	gtk_window_present (window);
-}
-
-static void
-show_evolution (gpointer arg0, gpointer arg1)
+show_evolution (gpointer arg0, guint timestamp, gpointer arg1)
 {
 #define MAIL_ICON "evolution-mail"
   EShell *shell = evo_shell;
@@ -1009,7 +1014,8 @@ show_evolution (gpointer arg0, gpointer arg1)
         return;
     }
 
-    really_present_window (mail_window);
+    gtk_window_present_with_time (mail_window, timestamp);
+
     for (i = indicators; i; i = i->next)
     {
       IndicateIndicator *indicator = i->data;
